@@ -91,6 +91,15 @@ public:
          */
         virtual void activating(MappedRegistry *user);
 
+        /**
+         * Resolve remote uri's.
+         * @param host of remote server.
+         * @param port of remote server (0 = unspecified/srv).
+         * @param addr buffer to use.
+         * @return true if resolved.
+         */
+        virtual bool resolve(const char *uri , struct sockaddr_storage *addr);
+
         /**
          * Notify plugins a user registration has been expired or released.
          * @param user registration that was expired.
